input[type="button"].notTriggerableTransitionButton {
    background: #ffd5c0 url("notTriggerableTransition.gif") no-repeat scroll 6px 4px;
    font-style: italic;
    cursor: help;
    padding-left: 15px;
    color: #474747;
}

.notTriggerableTransitionImage {
    background: #ffd5c0 url("notTriggerableTransition.gif") no-repeat scroll 1px 1px;
    font-style: italic;
    cursor: help;
    padding: 0 1px 0 7px;
    border-radius: 5px;
    border: 1px solid red;
    margin-left: 0.2em;
}

#content table.actionspanel-no-style-table,
#content table.actionspanel-no-style-table tr,
#content table.actionspanel-no-style-table tr td {
    border: 0 !important;
    padding: 0 !important;
    margin: 0 !important;
}

span#content-history.highlight-history-link a {
    color: red;
    font-weight: bold;
}

div.popupbuttons {
    text-align: center;
    padding-top: 1em;
}

/* setup img with/height necessary for tooltipster */
table.actionspanel-no-style-table img {
    width: 16px;
    height: 16px;
}
